@@ -1,6 +1,6 @@
 """PyUSB virtual FTDI device."""
 
-# Copyright (c) 2020, Emmanuel Blot <emmanuel.blot@free.fr>
+# Copyright (c) 2020-2021, Emmanuel Blot <emmanuel.blot@free.fr>
 # All rights reserved.
 #
 # SPDX-License-Identifier: BSD-3-Clause
@@ -33,11 +33,6 @@ from .consts import FTDICONST, USBCONST
 from .mpsse import VirtMpsseEngine, VirtMpsseTracer
 
 
-# need support for f-string syntax
-if version_info[:2] < (3, 6):
-    raise AssertionError('Python 3.6 is required for this module')
-
-
 class Pipe:
     """Wrapper around os.pipe
     """
@@ -308,8 +303,8 @@ class VirtFtdiPort:
         self._rx_thread.start()
         self._tx_thread.start()
 
-    def terminate(self):
-        self.log.debug('> terminate')
+    def close(self, freeze: bool = False) -> None:
+        self.log.debug('> close %d', freeze)
         if self._tx_thread:
             with self._cmd_q.lock:
                 self._cmd_q.q.append((self.Command.TERMINATE,))
@@ -328,6 +323,9 @@ class VirtFtdiPort:
             self._tx_thread.join()
             self._tx_thread = None
 
+    def terminate(self):
+        self.close()
+
     def __getitem__(self, index: int) -> VirtualFtdiPin:
         if not isinstance(index, int):
             raise TypeError(f"sequence index must be integer, "
@@ -991,9 +989,12 @@ class VirtFtdi:
         for iface in range(self.PROPERTIES[self._version].ifcount):
             self._ports.append(VirtFtdiPort(self, iface+1))
 
-    def terminate(self):
+    def close(self, freeze: bool = False) -> None:
         for port in self._ports:
-            port.terminate()
+            port.close(freeze)
+
+    def terminate(self):
+        self.close()
 
     @property
     def version(self) -> int:
